# load libraries
library(nhdplusTools)
library(sf)

nhdplusTools_data_dir(dir = "data")

# load extent of map
extent <- read.csv(file = "extent.csv")
crs <- 4269

extent_poly <- st_polygon(
  x = list(
    cbind(
      extent$longitude[c(1,2,2,1,1)], 
      extent$latitude[c(1,1,2,2,1)])
  )
)

extent_poly <- st_sfc(extent_poly, crs=4326)
extent_bbox <- st_bbox(st_transform(x = extent_poly, crs))
extent <- list(longitude_max = max(extent$longitude),
               longitude_min = min(extent$longitude),
               latitude_max = max(extent$latitude),
               latitude_min = min(extent$latitude))


# get watershed areas
extent_huc <- get_huc(AOI = extent_poly, buffer = 0, type = "huc04")

# download data
download_nhdplushr("data", extent_huc$huc4, download_files = TRUE)

# combine data into geopackage
data <- get_nhdplushr(hr_dir = "data", 
                      out_gpkg = "data/data.gpkg",
                      layers = NULL)